@@ -22,6 +22,7 @@
 #' @param mode Character string: whether to use the standard method (circle), or simple random placement (random)
 #' @param minalloweddist Numerical value: minimum distance between the randomised cluster centers, otherwise repeat randomisation
 #' @param pcafontsize Numerical value: the font size of the pca
+#' @param showplots Logical flag: whether to remove the plots
 #'
 #' @return A list, containing: 
 #' 1) the synthetic data
@@ -37,7 +38,7 @@
 clusterlab <- function(centers=1,r=8,sdvec=NULL,alphas=NULL,centralcluster=FALSE,
                        numbervec=NULL,features=500,seed=NULL,rings=NULL,ringalphas=NULL,
                        ringthetas=NULL,outliers=NULL,outlierdist=NULL,mode=c('circle','random'),
-                       minalloweddist=0,pcafontsize=18){
+                       minalloweddist=0,pcafontsize=18,showplots=TRUE){
   
   mode <- match.arg(mode)
   message('***clusterlab***')
@@ -293,14 +294,16 @@ clusterlab <- function(centers=1,r=8,sdvec=NULL,alphas=NULL,centralcluster=FALSE
     pca1 = prcomp(mydata)
     scores <- data.frame(pca1$x) # PC score matrix
     # plot example
-    p <- ggplot(data = scores, aes_string(x = 'PC1', y = 'PC2', colour = identitymatrix$cluster) ) + geom_point(size=3) +
-      theme_bw() + 
-      theme(legend.position = "none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
-            axis.text.y = element_text(size = pcafontsize, colour = 'black'),
-            axis.text.x = element_text(size = pcafontsize, colour = 'black'),
-            axis.title.x = element_text(size = pcafontsize),
-            axis.title.y = element_text(size = pcafontsize))
-    print(p)
+    if (showplots == TRUE){
+      p <- ggplot(data = scores, aes_string(x = 'PC1', y = 'PC2', colour = identitymatrix$cluster) ) + geom_point(size=3) +
+        theme_bw() + 
+        theme(legend.position = "none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
+              axis.text.y = element_text(size = pcafontsize, colour = 'black'),
+              axis.text.x = element_text(size = pcafontsize, colour = 'black'),
+              axis.title.x = element_text(size = pcafontsize),
+              axis.title.y = element_text(size = pcafontsize))
+      print(p)
+    }
     mydata <- data.frame(t(mydata))
     colnames(mydata) <- identitymatrix$sampleID
     
@@ -367,14 +370,16 @@ clusterlab <- function(centers=1,r=8,sdvec=NULL,alphas=NULL,centralcluster=FALSE
     pca1 = prcomp(mydata)
     scores <- data.frame(pca1$x) # PC score matrix
     # plot example
-    p <- ggplot(data = scores, aes_string(x = 'PC1', y = 'PC2', colour = identitymatrix$cluster) ) + geom_point(size=3) +
-      theme_bw() + 
-      theme(legend.position = "none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
-            axis.text.y = element_text(size = pcafontsize, colour = 'black'),
-            axis.text.x = element_text(size = pcafontsize, colour = 'black'),
-            axis.title.x = element_text(size = pcafontsize),
-            axis.title.y = element_text(size = pcafontsize))
-    print(p)
+    if (showplots == TRUE){
+      p <- ggplot(data = scores, aes_string(x = 'PC1', y = 'PC2', colour = identitymatrix$cluster) ) + geom_point(size=3) +
+        theme_bw() + 
+        theme(legend.position = "none", panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
+              axis.text.y = element_text(size = pcafontsize, colour = 'black'),
+              axis.text.x = element_text(size = pcafontsize, colour = 'black'),
+              axis.title.x = element_text(size = pcafontsize),
+              axis.title.y = element_text(size = pcafontsize))
+      print(p)
+    }
     mydata <- data.frame(t(mydata))
     
     newlist <- list('synthetic_data' = mydata, 'identity_matrix' = identitymatrix)
